==> myfaces-core-assembly-2.3.9-src.zip: org/apache/myfaces/spi/impl/CDIAnnotationDelegateInjectionProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.spi.impl;

import javax.faces.context.ExternalContext;
import org.apache.myfaces.shared.util.ClassUtils;
import org.apache.myfaces.spi.InjectionProvider;
import org.apache.myfaces.spi.InjectionProviderException;
import org.apache.myfaces.util.ExternalSpecifications;

/**
 * Delegation pattern to avoid direct instantiation
 */
public class CDIAnnotationDelegateInjectionProvider extends InjectionProvider
{
    private InjectionProvider delegate;
    private final boolean available;
    
    public CDIAnnotationDelegateInjectionProvider(ExternalContext externalContext)
    {
        if (ExternalSpecifications.isCDIAvailable(externalContext))
        {
            try
            {
                Class clazz = ClassUtils.simpleClassForName(
                    "org.apache.myfaces.cdi.impl.CDIAnnotationInjectionProvider");
                delegate = (InjectionProvider) clazz.getConstructor(
                    ExternalContext.class).newInstance(externalContext);
            }
            catch(Exception e)
            {
                //Ignore
            }
        }
        available = (delegate != null);
    }

    @Override
    public Object inject(Object instance) throws InjectionProviderException
    {
        if (available)
        {
            return delegate.inject(instance);
        }
        return null;
    }

    @Override
    public void postConstruct(Object instance, Object creationMetaData) throws InjectionProviderException
    {
        if (available)
        {
            delegate.postConstruct(instance, creationMetaData);
        }
    }

    @Override
    public void preDestroy(Object instance, Object creationMetaData) throws InjectionProviderException
    {
        if (available)
        {
            delegate.preDestroy(instance, creationMetaData);
        }
    }

    @Override
    public boolean isAvailable()
    {
        return available;
    }
}

==> myfaces-core-assembly-3.0.2-src.zip: org/apache/myfaces/spi/impl/CDIAnnotationDelegateInjectionProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.spi.impl;

import jakarta.faces.context.ExternalContext;
import org.apache.myfaces.shared.util.ClassUtils;
import org.apache.myfaces.spi.InjectionProvider;
import org.apache.myfaces.spi.InjectionProviderException;
import org.apache.myfaces.util.ExternalSpecifications;

/**
 * Delegation pattern to avoid direct instantiation
 */
public class CDIAnnotationDelegateInjectionProvider extends InjectionProvider
{
    private InjectionProvider delegate;
    private final boolean available;
    
    public CDIAnnotationDelegateInjectionProvider(ExternalContext externalContext)
    {
        if (ExternalSpecifications.isCDIAvailable(externalContext))
        {
            try
            {
                Class clazz = ClassUtils.simpleClassForName(
                    "org.apache.myfaces.cdi.impl.CDIAnnotationInjectionProvider");
                delegate = (InjectionProvider) clazz.getConstructor(
                    ExternalContext.class).newInstance(externalContext);
            }
            catch(Exception e)
            {
                //Ignore
            }
        }
        available = (delegate != null);
    }

    @Override
    public Object inject(Object instance) throws InjectionProviderException
    {
        if (available)
        {
            return delegate.inject(instance);
        }
        return null;
    }

    @Override
    public void postConstruct(Object instance, Object creationMetaData) throws InjectionProviderException
    {
        if (available)
        {
            delegate.postConstruct(instance, creationMetaData);
        }
    }

    @Override
    public void preDestroy(Object instance, Object creationMetaData) throws InjectionProviderException
    {
        if (available)
        {
            delegate.preDestroy(instance, creationMetaData);
        }
    }

    @Override
    public boolean isAvailable()
    {
        return available;
    }
}
